"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useDocumentTitle = void 0;
var react_1 = require("react");
var useIsomorphicLayoutEffect_1 = require("../useIsomorphicLayoutEffect");
var useUnmount_1 = require("../useUnmount");
/**
 * A hook to set the document title.
 * @param {string} title - The title to set.
 * @param {?Options} [options] - The options.
 * @param {?boolean} [options.preserveTitleOnUnmount] - Whether to keep the title after unmounting the component (default is `true`).
 * @see [Documentation](https://usehooks-ts.com/react-hook/use-document-title)
 * @example
 * useDocumentTitle('My new title');
 */
function useDocumentTitle(title, options) {
    if (options === void 0) { options = {}; }
    var _a = options.preserveTitleOnUnmount, preserveTitleOnUnmount = _a === void 0 ? true : _a;
    var defaultTitle = (0, react_1.useRef)(null);
    (0, useIsomorphicLayoutEffect_1.useIsomorphicLayoutEffect)(function () {
        defaultTitle.current = window.document.title;
    }, []);
    (0, useIsomorphicLayoutEffect_1.useIsomorphicLayoutEffect)(function () {
        window.document.title = title;
    }, [title]);
    (0, useUnmount_1.useUnmount)(function () {
        if (!preserveTitleOnUnmount && defaultTitle.current) {
            window.document.title = defaultTitle.current;
        }
    });
}
exports.useDocumentTitle = useDocumentTitle;
