"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useEventCallback = void 0;
var react_1 = require("react");
var useIsomorphicLayoutEffect_1 = require("../useIsomorphicLayoutEffect");
/**
 * A hook for creating a memoized event callback.
 * @template Args - An array of argument types for the event callback.
 * @template R - The return type of the event callback.
 * @param {(...args: Args) => R} fn - The callback function.
 * @returns {(...args: Args) => R} A memoized event callback function.
 * @example
 * const handleClick = useEventCallback((event) => {
 *   // Handle the event here
 * });
 */
function useEventCallback(fn) {
    var ref = (0, react_1.useRef)(function () {
        throw new Error('Cannot call an event handler while rendering.');
    });
    (0, useIsomorphicLayoutEffect_1.useIsomorphicLayoutEffect)(function () {
        ref.current = fn;
    }, [fn]);
    return (0, react_1.useCallback)(function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        return ref.current.apply(ref, args);
    }, [ref]);
}
exports.useEventCallback = useEventCallback;
