"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useIsFirstRender = void 0;
var react_1 = require("react");
/**
 * Custom hook for determining if the component is rendering for the first time.
 * @returns {boolean} A boolean value indicating whether the component is rendering for the first time.
 * @see [Documentation](https://usehooks-ts.com/react-hook/use-is-first-render)
 * @example
 * const isFirstRender = useIsFirstRender();
 * // Use isFirstRender to conditionally execute code only on the initial render.
 */
function useIsFirstRender() {
    var isFirst = (0, react_1.useRef)(true);
    if (isFirst.current) {
        isFirst.current = false;
        return true;
    }
    return isFirst.current;
}
exports.useIsFirstRender = useIsFirstRender;
