/**
 * Custom hook for locking and unlocking the body scroll to prevent scrolling.
 * @param {?boolean} [initialLocked] - The initial state of body scroll lock (default to `false`).
 * @param {?string} [rootId] - The ID of the root element to calculate scrollbar width (default to `___gatsby` to not introduce breaking change).
 * @returns {[boolean, (locked: boolean) => void]} A tuple containing the current state of body scroll lock and a function to set the state.
 * @see [Documentation](https://usehooks-ts.com/react-hook/use-locked-body)
 * @example
 * const [isLocked, setLocked] = useLockedBody(true);
 * // Use isLocked to conditionally apply styles or prevent scrolling.
 * // Use setLocked to dynamically control the body scroll lock state.
 */
export declare function useLockedBody(initialLocked?: boolean, rootId?: string): [boolean, (locked: boolean) => void];
