"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useOnClickOutside = void 0;
var useEventListener_1 = require("../useEventListener");
/**
 * Custom hook for handling clicks outside a specified element.
 * @template T - The type of the element's reference.
 * @param {RefObject<T>} ref - The React ref object representing the element to watch for outside clicks.
 * @param {(event: MouseEvent) => void} handler - The callback function to be executed when a click outside the element occurs.
 * @param {'mousedown' | 'mouseup'} [mouseEvent] - The mouse event type to listen for (optional, default is 'mousedown').
 * @returns {void}
 * @see [Documentation](https://usehooks-ts.com/react-hook/use-on-click-outside)
 * @example
 * const containerRef = useRef(null);
 * useOnClickOutside(containerRef, () => {
 *   // Handle clicks outside the container.
 * });
 */
function useOnClickOutside(ref, handler, mouseEvent) {
    if (mouseEvent === void 0) { mouseEvent = 'mousedown'; }
    (0, useEventListener_1.useEventListener)(mouseEvent, function (event) {
        var el = ref.current;
        // Do nothing if clicking ref's element or descendent elements
        if (!el || el.contains(event.target)) {
            return;
        }
        handler(event);
    });
}
exports.useOnClickOutside = useOnClickOutside;
