"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useUnmount = void 0;
var react_1 = require("react");
/**
 * Hook that runs a cleanup function when the component is unmounted.
 * @param {() => void} func - The cleanup function to be executed on unmount.
 * @see [Documentation](https://usehooks-ts.com/react-hook/use-unmount)
 * @example
 * // Usage in a functional component
 * useUnmount(() => {
 *   // Cleanup logic here
 * });
 */
function useUnmount(func) {
    var funcRef = (0, react_1.useRef)(func);
    funcRef.current = func;
    (0, react_1.useEffect)(function () { return function () {
        funcRef.current();
    }; }, []);
}
exports.useUnmount = useUnmount;
